<?php
/**
 * WP-WebsiteToolbox Events
 */
namespace WebsiteToolboxEvents;
use WebsiteToolboxForum;
use WebsiteToolboxAdmin;
/* Purpose: If a user deleted from WordPress site then delete from Forum.
Parameter: None
Return: None */
function deleteForumUser($args) {
    global $wpdb;
    #get All the user id's deleted from wordpress site.
    $userids = implode(",", $_POST['users']);
    #Get username from users table on the basis of userids.
    $user_names = $wpdb->get_results( "
        SELECT user_login
        FROM $wpdb->users
        WHERE ID IN ($userids)" );
    $unames = array();
    foreach ( $user_names as $usernames ) {
        $unames[] = $usernames->user_login;
    }
    #create a comma(,) separated string to sent user delete request on the Forum.
    if ( $unames ) {
        $usernames = implode(",", $unames);
    }
    $forum_api      = get_option("websitetoolbox_api");
    $forum_url      = get_option("websitetoolbox_url");
    // create URL to to delete users from related Forum.
    $URL = $forum_url."/register";
    $fields = array(
            'apikey' => $forum_api,
            'massaction' => 'decline_mem',
            'usernames' => $usernames
        );
    // Send http or https request to get authentication token.
    $response_array = wp_remote_post($URL, array('method' => 'POST', 'body' => $fields));
    if(!is_wp_error( $response_array )) {
        $response = trim(wp_remote_retrieve_body($response_array));
        // Decode json string
        $response = json_decode($response);
        if($response->{'success'}) {
            return true;
        }
    }
}


/* Purpose: sent HTTP request for get authtoken if user try to login on the WordPress website.
Parameter: None
Return: None */
function getAuthtokenForLogin($user_login) {
    $userObj = new \WP_User(0,$user_login);
    $userRoles       = (array) json_decode(get_option('websitetoolbox_user_roles'));
    $currentUserRole = $user_obj->roles[0];
    $key             = array_search($currentUserRole, $userRoles);
    if (is_numeric($key)) {
        $responseArray = WebsiteToolboxForum\ssoHttpRequest($userObj);
        WebsiteToolboxForum\setCookieOnLogin($responseArray, $_POST['rememberme']);
        #Save authentication token into session variable.
        WebsiteToolboxForum\saveAuthToken($responseArray['authtoken'],$responseArray['wtbUserid']);
        WebsiteToolboxForum\afterLoginRedirection($responseArray['authtoken']);
        return true;
    }
}


/* Purpose: execute HTTP request to create an account on the related forum once user create account on the WordPress website.
Parameter: None
Return: None */
function createUserOnForum($userid) {
    $user_obj = new \WP_User($userid);
    $userRoles       = (array) json_decode(get_option('websitetoolbox_user_roles'));
    $currentUserRole = $user_obj->roles[0];
    $key             = array_search($currentUserRole, $userRoles);
    if (is_numeric($key)) {
        $forum_api      = get_option("websitetoolbox_api");
        $forum_url      = get_option("websitetoolbox_url");
        if($forum_api) {
            $login_id = $user_obj->ID;
            $login    = $user_obj->user_login; # ie: JohnD223

            // pass1 used for password filed (WordPress Registration form) in older version (below 4.3).
            // pass1-text used for password filed in WordPress versions (4.3 and above).
            // Pass this password into SSO regisration request if not peresent then sent blank password.
            if (isset($_POST['pass1']) && $_POST['pass1'] != "") {
                $password = $_POST['pass1'];
            } elseif (isset($_POST['pass1-text']) && $_POST['pass1-text'] != "") {
                $password = $_POST['pass1-text'];
            } else {
                $password = '';
            }

            $email    = $user_obj->user_email;
            $display_name = $user_obj->display_name; # ie: John Doe
            $first_name = $user_obj->first_name; # ie: John
            $last_name = $user_obj->last_name; # ie: Doe
            $fullname = trim($first_name." ".$last_name);
            $externalUserid=$user_obj->ID;

            // URL to create a new account on forum.
            $URL = $forum_url."/register/create_account";
            // Fields array.
            $fields = array(
                'apikey'         => $forum_api,
                'member'         => $login,
                'pw'             => $password,
                'email'          => $email,
                'name'           => $fullname,
                'avatar'         => get_avatar_url($externalUserid),
                'externalUserid' => $externalUserid
            );
            // Sent https/https request on related forum to create an account on the related forum.
            $response_array = wp_remote_post($URL, array('method' => 'POST', 'body' => $fields));
            return true;
        }
    }
}


/* Purpose: sent logout request to forum once user logged-out from the WordPress website.
Parameter: none
Return: none */
function logoutUserOnForum() {
    if(!is_user_logged_in() && isset($_COOKIE['wt_logout_token'])) {
        global $wp;
        // Preapred logut URL for forum and append redirect URL into it so that user redirected to related page after logout from the forum.
        $forum_url  = get_option("websitetoolbox_url");
        //redirect to forum first to logout if forum is not on sub-domain
        if(WebsiteToolboxAdmin\getDomainName(get_site_url()) != WebsiteToolboxAdmin\getDomainName($forum_url)){
            $forum_url .= '/register/logout?redirect=';
            if(isset($_REQUEST['redirect_to'])) {
                $redirec_url = $_REQUEST['redirect_to'];
            } else if(isset($_REQUEST['wtbForumUrl'])) {
                $redirec_url = $_REQUEST['wtbForumUrl'];
            } else if(get_permalink() ) {
                $redirec_url = get_permalink();
            } else {
                $redirec_url = wp_get_referer();
                if(strpos($redirec_url, "action=logout")) {
                    $redirec_url = str_replace('action=logout', '', $redirec_url) ;
                }
            }
            //Remove (authtoken, wtlogin) parameters and values from the URL if exist in the URL after logout.
            $redirec_url = WebsiteToolboxForum\removeParam($redirec_url,"authtoken");
            $redirec_url = WebsiteToolboxForum\removeParam($redirec_url,"wtlogin");
            $redirec_url = urldecode($redirec_url);

            //Setting redirection URL based on frontend or backend logout
            //$word defined to look for string wp-admin in redirect_url
            $word="wp-admin";
            if(strpos($redirec_url, $word) !== false){
                $redirec_url = wp_login_url( $redirec_url );
            }else{
                $redirec_url = home_url();
            }

            $wtbLogoutUrl = $forum_url.urlencode($redirec_url);
            //If user is already logged out on forum
            startForumSession();
            if(isset($_SESSION['wtb_logout_referer']) && $_SESSION['wtb_logout_referer']!="" ) {
                $wtbLogoutUrl= home_url();
                unset($_SESSION['wtb_logout_referer']);
            }
            WebsiteToolboxForum\resetCookieOnLogout();
            wp_redirect($wtbLogoutUrl);
            exit;
        }
    }
}


/* Purpose: Update user information the forum.
Parameter: logged-in userid, user data
Return: none */
function updateUserOnForum($wpProfileUserid, $oldUserData) {
    // Get logged-in userid of the WordPress website.
    $wpLoggedinUserid = get_current_user_id();
    // change updated userid if admin update other user profile else get update userid from the cookie.
    // WTB logged-in userid store in the cookie when user logged-in on the WordPress website.
    if($wpLoggedinUserid != $wpProfileUserid) {
        $wpUserid = $oldUserData->ID;
        $wtbUserid =  WebsiteToolboxForum\getUserid($oldUserData->user_email);
    } else {
        $wpUserid = $wpProfileUserid;
        $wtbUserid = $_COOKIE['wtb_login_userid'];
    }
    // Update user data on the forum.
    if($wtbUserid) {
        $userObj = new \WP_User($wpUserid);
        $data =  array(
            "username"  => $userObj->user_login,
            "email"     => $userObj->user_email,
            "name"      => trim($userObj->first_name." ".$userObj->last_name),
            "avatarUrl" => get_avatar_url($wpUserid),
            'externalUserid' => $userObj->ID
        );
        WebsiteToolboxForum\apiRequest('POST', "/users/$wtbUserid", $data);
    }
}

?>